@@ -1089,36 +1089,24 @@ int ha_myisam::repair(THD *thd, MI_CHECK &param, bool do_optimize)
         /* TODO: respect myisam_repair_threads variable */
         my_snprintf(buf, 40, "Repair with %d threads", my_count_bits(key_map));
         thd_proc_info(thd, buf);
-        /*
-          The new file is created with the right stats, so we can skip
-          copying file stats from old to new.
-        */
         error = mi_repair_parallel(&param, file, fixed_name,
-                                   param.testflag & T_QUICK, TRUE);
+            param.testflag & T_QUICK);
         thd_proc_info(thd, "Repair done"); // to reset proc_info, as
                                       // it was pointing to local buffer
       }
       else
       {
         thd_proc_info(thd, "Repair by sorting");
-        /*
-          The new file is created with the right stats, so we can skip
-          copying file stats from old to new.
-        */
         error = mi_repair_by_sort(&param, file, fixed_name,
-                                  param.testflag & T_QUICK, TRUE);
+            param.testflag & T_QUICK);
       }
     }
     else
     {
       thd_proc_info(thd, "Repair with keycache");
       param.testflag &= ~T_REP_BY_SORT;
-      /*
-        The new file is created with the right stats, so we can skip
-        copying file stats from old to new.
-      */
       error=  mi_repair(&param, file, fixed_name,
-			param.testflag & T_QUICK, TRUE);
+			param.testflag & T_QUICK);
     }
 #ifdef HAVE_MMAP
     if (remap)
@@ -1134,11 +1122,7 @@ int ha_myisam::repair(THD *thd, MI_CHECK &param, bool do_optimize)
     {
       optimize_done=1;
       thd_proc_info(thd, "Sorting index");
-      /*
-        The new file is created with the right stats, so we can skip
-        copying file stats from old to new.
-      */
-      error=mi_sort_index(&param,file,fixed_name, TRUE);
+      error=mi_sort_index(&param,file,fixed_name);
     }
     if (!statistics_done && (local_testflag & T_STATISTICS))
     {
