@@ -1,4 +1,5 @@
-/* Copyright (c) 2003-2006 MySQL AB
+/*
+   Copyright (c) 2003, 2010, Oracle and/or its affiliates. All rights reserved.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -11,7 +12,8 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
+   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
+*/
 
 #ifndef NDBT_TABLE_HPP
 #define NDBT_TABLE_HPP
@@ -29,7 +31,10 @@ public:
 		 bool _pk = false, 
 		 bool _nullable = false,
 		 CHARSET_INFO *cs= 0,
-		 NdbDictionary::Column::StorageType storage = NdbDictionary::Column::StorageTypeMemory):
+		 NdbDictionary::Column::StorageType storage = NdbDictionary::Column::StorageTypeMemory,
+                 bool dynamic = false,
+                 const void* defaultVal = NULL,
+                 Uint32 defaultValBytes = 0):
     NdbDictionary::Column(_name)
   {
     assert(_name != 0);
@@ -43,6 +48,8 @@ public:
       setCharset(cs);
     }
     setStorageType(storage);
+    setDynamic(dynamic);
+    setDefaultValue(defaultVal, defaultValBytes);
   }
 };
 
@@ -68,9 +75,27 @@ public:
     // validate() might cause initialization order problem with charset
     NdbError error;
     int ret = aggregate(error);
+    (void)ret;
     assert(ret == 0);
   }
 
+  NDBT_Table(const char* name, 
+	     int noOfAttributes,
+	     NdbDictionary::Column* attributePtrs[])
+    : NdbDictionary::Table(name)
+  {
+    assert(name != 0);
+    
+    //setStoredTable(stored);
+    for(int i = 0; i<noOfAttributes; i++)
+      addColumn(*attributePtrs[i]);
+    
+    // validate() might cause initialization order problem with charset
+    NdbError error;
+    int ret = aggregate(error);
+    assert(ret == 0);
+  }
+  
   static const NdbDictionary::Table * discoverTableFromDb(Ndb* ndb,
 							  const char * name);
 };
