@@ -1,5 +1,6 @@
-/* Copyright (c) 2003-2005 MySQL AB
-   Use is subject to license terms
+/*
+   Copyright (C) 2003-2006 MySQL AB, 2009 Sun Microsystems, Inc.
+    All rights reserved. Use is subject to license terms.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -12,7 +13,8 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA */
+   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
+*/
 
 
 #include <ndb_global.h>
@@ -31,7 +33,7 @@ int main(int argc, const char** argv){
   ndb_init();
   int _help = 0;
   int _wait = 30;
-  char * _database="BANK";
+  const char * _database="BANK";
   
   struct getargs args[] = {
     { "wait", 'w', arg_integer, &_wait, "Max time to wait between days", "secs" },
